@@ -58,6 +58,8 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayListProxyModel *playListControle
             this, &MediaPlayer2Player::playerIsSeekableChanged);
     connect(m_manageAudioPlayer, &ManageAudioPlayer::playerPositionChanged,
             this, &MediaPlayer2Player::audioPositionChanged);
+    connect(m_manageAudioPlayer, &ManageAudioPlayer::seek,
+            this, &MediaPlayer2Player::playerSeeked);
     connect(m_manageAudioPlayer, &ManageAudioPlayer::audioDurationChanged,
             this, &MediaPlayer2Player::audioDurationChanged);
     connect(m_audioPlayer, &AudioWrapper::volumeChanged,
@@ -116,7 +118,7 @@ bool MediaPlayer2Player::CanGoNext() const
 
 void MediaPlayer2Player::Next()
 {
-    emit next();
+    Q_EMIT next();
 
     if (m_playListControler) {
         m_playListControler->skipNextTrack();
@@ -130,10 +132,10 @@ bool MediaPlayer2Player::CanGoPrevious() const
 
 void MediaPlayer2Player::Previous()
 {
-    emit previous();
+    Q_EMIT previous();
 
     if (m_playListControler) {
-        m_playListControler->skipPreviousTrack();
+        m_playListControler->skipPreviousTrack(m_audioPlayer->position());
     }
 }
 
@@ -151,7 +153,7 @@ void MediaPlayer2Player::Pause()
 
 void MediaPlayer2Player::PlayPause()
 {
-    emit playPause();
+    Q_EMIT playPause();
 
     if (m_playListControler) {
         m_manageAudioPlayer->playPause();
@@ -160,7 +162,7 @@ void MediaPlayer2Player::PlayPause()
 
 void MediaPlayer2Player::Stop()
 {
-    emit stop();
+    Q_EMIT stop();
 
     if (m_playListControler) {
         m_manageAudioPlayer->stop();
@@ -187,7 +189,7 @@ double MediaPlayer2Player::Volume() const
 void MediaPlayer2Player::setVolume(double volume)
 {
     m_volume= qBound(0.0, volume, 1.0);
-    emit volumeChanged(m_volume);
+    Q_EMIT volumeChanged(m_volume);
 
     m_audioPlayer->setVolume(100 * m_volume);
 
@@ -208,9 +210,7 @@ void MediaPlayer2Player::setPropertyPosition(int newPositionInMs)
 {
     m_position = qlonglong(newPositionInMs) * 1000;
 
-    Q_EMIT Seeked(m_position);
-
-    /* only sent new progress when it has advanced more than 1 %
+    /* only send new progress when it has advanced more than 1 %
      * to limit DBus traffic
      */
     const auto incrementalProgress = static_cast<double>(newPositionInMs - mPreviousProgressPosition) / m_audioPlayer->duration();
@@ -238,7 +238,7 @@ void MediaPlayer2Player::setRate(double newRate)
         Pause();
     } else {
         m_rate = qBound(MinimumRate(), newRate, MaximumRate());
-        emit rateChanged(m_rate);
+        Q_EMIT rateChanged(m_rate);
 
         signalPropertiesChange(QStringLiteral("Rate"), Rate());
     }
@@ -272,11 +272,6 @@ void MediaPlayer2Player::Seek(qlonglong Offset)
     }
 }
 
-void MediaPlayer2Player::emitSeeked(int pos)
-{
-    emit Seeked(qlonglong(pos) * 1000);
-}
-
 void MediaPlayer2Player::SetPosition(const QDBusObjectPath &trackId, qlonglong pos)
 {
     if (trackId.path() == m_currentTrackId) {
@@ -309,8 +304,8 @@ void MediaPlayer2Player::playControlEnabledChanged()
     signalPropertiesChange(QStringLiteral("CanPause"), CanPause());
     signalPropertiesChange(QStringLiteral("CanPlay"), CanPlay());
 
-    emit canPauseChanged();
-    emit canPlayChanged();
+    Q_EMIT canPauseChanged();
+    Q_EMIT canPlayChanged();
 }
 
 void MediaPlayer2Player::skipBackwardControlEnabledChanged()
@@ -322,7 +317,7 @@ void MediaPlayer2Player::skipBackwardControlEnabledChanged()
     m_canGoPrevious = m_manageMediaPlayerControl->skipBackwardControlEnabled();
 
     signalPropertiesChange(QStringLiteral("CanGoPrevious"), CanGoPrevious());
-    emit canGoPreviousChanged();
+    Q_EMIT canGoPreviousChanged();
 }
 
 void MediaPlayer2Player::skipForwardControlEnabledChanged()
@@ -334,13 +329,13 @@ void MediaPlayer2Player::skipForwardControlEnabledChanged()
     m_canGoNext = m_manageMediaPlayerControl->skipForwardControlEnabled();
 
     signalPropertiesChange(QStringLiteral("CanGoNext"), CanGoNext());
-    emit canGoNextChanged();
+    Q_EMIT canGoNextChanged();
 }
 
 void MediaPlayer2Player::playerPlaybackStateChanged()
 {
     signalPropertiesChange(QStringLiteral("PlaybackStatus"), PlaybackStatus());
-    emit playbackStatusChanged();
+    Q_EMIT playbackStatusChanged();
 
     playerIsSeekableChanged();
 }
@@ -350,7 +345,7 @@ void MediaPlayer2Player::playerIsSeekableChanged()
     m_playerIsSeekableChanged = m_manageAudioPlayer->playerIsSeekable();
 
     signalPropertiesChange(QStringLiteral("CanSeek"), CanSeek());
-    emit canSeekChanged();
+    Q_EMIT canSeekChanged();
 }
 
 void MediaPlayer2Player::audioPositionChanged()
@@ -358,6 +353,11 @@ void MediaPlayer2Player::audioPositionChanged()
     setPropertyPosition(static_cast<int>(m_manageAudioPlayer->playerPosition()));
 }
 
+void MediaPlayer2Player::playerSeeked(qint64 position)
+{
+    Q_EMIT Seeked(position * 1000);
+}
+
 void MediaPlayer2Player::audioDurationChanged()
 {
     m_metadata = getMetadataOfCurrentTrack();
@@ -385,13 +385,20 @@ void MediaPlayer2Player::setCurrentTrack(int newTrackPosition)
     m_currentTrack = m_manageAudioPlayer->playerSource().toString();
     m_currentTrackId = QDBusObjectPath(QLatin1String("/org/kde/elisa/playlist/") + QString::number(newTrackPosition)).path();
 
-    emit currentTrackChanged();
+    Q_EMIT currentTrackChanged();
+
+    m_metadata = getMetadataOfCurrentTrack();
+    signalPropertiesChange(QStringLiteral("Metadata"), Metadata());
 }
 
 QVariantMap MediaPlayer2Player::getMetadataOfCurrentTrack()
 {
     auto result = QVariantMap();
 
+    if (m_currentTrackId.isEmpty()) {
+        return {};
+    }
+
     result[QStringLiteral("mpris:trackid")] = QVariant::fromValue<QDBusObjectPath>(QDBusObjectPath(m_currentTrackId));
     result[QStringLiteral("mpris:length")] = qlonglong(m_manageAudioPlayer->audioDuration()) * 1000;
     //convert milli-seconds into micro-seconds
@@ -459,16 +466,16 @@ void MediaPlayer2Player::setMediaPlayerPresent(int status)
 {
     if (m_mediaPlayerPresent != status) {
         m_mediaPlayerPresent = status;
-        emit mediaPlayerPresentChanged();
+        Q_EMIT mediaPlayerPresentChanged();
 
         signalPropertiesChange(QStringLiteral("CanGoNext"), CanGoNext());
         signalPropertiesChange(QStringLiteral("CanGoPrevious"), CanGoPrevious());
         signalPropertiesChange(QStringLiteral("CanPause"), CanPause());
         signalPropertiesChange(QStringLiteral("CanPlay"), CanPlay());
-        emit canGoNextChanged();
-        emit canGoPreviousChanged();
-        emit canPauseChanged();
-        emit canPlayChanged();
+        Q_EMIT canGoNextChanged();
+        Q_EMIT canGoPreviousChanged();
+        Q_EMIT canPauseChanged();
+        Q_EMIT canPlayChanged();
     }
 }
 
