@@ -1,23 +1,14 @@
 /*
- * Copyright 2016-2017 Matthieu Gallien <matthieu_gallien@yahoo.fr>
- *
- * This program is free software: you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-FileCopyrightText: 2016 (c) Matthieu Gallien <matthieu_gallien@yahoo.fr>
+
+   SPDX-License-Identifier: LGPL-3.0-or-later
  */
 
 #ifndef UPNPLISTENER_H
 #define UPNPLISTENER_H
 
+#include "datatypes.h"
+
 #include <QObject>
 #include <QVector>
 #include <QString>
@@ -27,9 +18,6 @@
 class UpnpListenerPrivate;
 
 class DatabaseInterface;
-class UpnpDiscoverAllMusic;
-class UpnpSsdpEngine;
-class MusicAudioTrack;
 
 class UpnpListener : public QObject
 {
@@ -56,7 +44,7 @@ Q_SIGNALS:
 
     void initialTracksListRequired(QString musicSource);
 
-    void initialTracksList(QString musicSource, QList<MusicAudioTrack> initialList);
+    void initialTracksList(QString musicSource, DataTypes::ListUpnpTrackDataType initialList);
 
 public Q_SLOTS:
 
