@@ -12,8 +12,12 @@
 #include "viewsLogging.h"
 #include "models/datamodel.h"
 #include "models/gridviewproxymodel.h"
+
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
 #include "models/filebrowsermodel.h"
 #include "models/filebrowserproxymodel.h"
+#endif
+
 #include "elisa_settings.h"
 
 #include <KI18n/KLocalizedString>
@@ -286,9 +290,14 @@ void ViewManager::openViewFromData(const ViewParameters &viewParamaters)
     {
     case FileBrowserModel:
     {
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
         newModel = new ::FileBrowserModel;
         auto *realProxyModel = new FileBrowserProxyModel;
         proxyModel = realProxyModel;
+#else
+        newModel = nullptr;
+        proxyModel = nullptr;
+#endif
         break;
     }
     case GenericDataModel:
@@ -403,7 +412,7 @@ QString ViewManager::buildViewId() const
     const auto &entryTypeMetaEnum = QMetaEnum::fromType<ElisaUtils::PlayListEntryType>();
     QString viewId;
 
-    for (const auto &oneView : qAsConst(d->mViewParametersStack)) {
+    for (const auto &oneView : std::as_const(d->mViewParametersStack)) {
         viewId += QString::fromLatin1(entryTypeMetaEnum.valueToKey(oneView.mDataType)) + QStringLiteral("::");
     }
 
